"""Top-level package for csverve."""


__author__ = """Shah Lab"""
__email__ = 'todo@todo.com'
__version__ = '0.2.3'


# csverve methods
from csverve.api import rewrite_csv_file
from csverve.api import merge_csv
from csverve.api import concatenate_csv
from csverve.api import simple_annotate_csv
from csverve.api import add_col_from_dict
from csverve.api import write_dataframe_to_csv_and_yaml
from csverve.api import read_csv
